@@ -60,3 +60,22 @@ test_that("can print workflow with >10 recipe steps", {
 
   expect_snapshot(add_recipe(workflow(), rec))
 })
+
+test_that("can print workflow with just case weights", {
+  workflow <- workflow()
+  workflow <- add_case_weights(workflow, disp)
+
+  expect_snapshot(workflow)
+})
+
+test_that("can print workflow with case weights, preprocessor, and model", {
+  model <- parsnip::linear_reg()
+  model <- parsnip::set_engine(model, "lm")
+
+  workflow <- workflow()
+  workflow <- add_formula(workflow, mpg ~ .)
+  workflow <- add_case_weights(workflow, disp)
+  workflow <- add_model(workflow, model)
+
+  expect_snapshot(workflow)
+})
